# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lofar_sid/interface/stationcontrol/statistics.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'lofar_sid/interface/stationcontrol/statistics.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3lofar_sid/interface/stationcontrol/statistics.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"J\n\rFrequencyBand\x12\x14\n\x0c\x61ntenna_type\x18\x01 \x01(\t\x12\r\n\x05\x63lock\x18\x02 \x01(\x05\x12\x14\n\x0cnyquist_zone\x18\x03 \x01(\x05\"C\n\nBstRequest\x12\x15\n\rantenna_field\x18\x01 \x01(\t\x12\x13\n\x06maxage\x18\x02 \x01(\rH\x00\x88\x01\x01\x42\t\n\x07_maxage\"\xf0\x01\n\tBstResult\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x0e\x66requency_band\x18\x02 \x01(\x0b\x32\x0e.FrequencyBand\x12\x1c\n\x14integration_interval\x18\x03 \x01(\x02\x12\'\n\x08\x62\x65\x61mlets\x18\x04 \x03(\x0b\x32\x15.BstResult.BstBeamlet\x1a\x45\n\nBstBeamlet\x12\x0f\n\x07\x62\x65\x61mlet\x18\x01 \x01(\x05\x12\x12\n\nx_power_db\x18\x02 \x01(\x02\x12\x12\n\ny_power_db\x18\x03 \x01(\x02\"&\n\x08\x42stReply\x12\x1a\n\x06result\x18\x03 \x01(\x0b\x32\n.BstResult\"C\n\nSstRequest\x12\x15\n\rantenna_field\x18\x01 \x01(\t\x12\x13\n\x06maxage\x18\x02 \x01(\rH\x00\x88\x01\x01\x42\t\n\x07_maxage\"\xd7\x02\n\tSstResult\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x0e\x66requency_band\x18\x02 \x01(\x0b\x32\x0e.FrequencyBand\x12\x1c\n\x14integration_interval\x18\x03 \x01(\x02\x12\'\n\x08subbands\x18\x04 \x03(\x0b\x32\x15.SstResult.SstSubband\x1a\xab\x01\n\nSstSubband\x12\x0f\n\x07subband\x18\x01 \x01(\x05\x12\x11\n\tfrequency\x18\x02 \x01(\x02\x12\x32\n\x08\x61ntennas\x18\x03 \x03(\x0b\x32 .SstResult.SstSubband.SstAntenna\x1a\x45\n\nSstAntenna\x12\x0f\n\x07\x61ntenna\x18\x01 \x01(\x05\x12\x12\n\nx_power_db\x18\x02 \x01(\x02\x12\x12\n\ny_power_db\x18\x03 \x01(\x02\"&\n\x08SstReply\x12\x1a\n\x06result\x18\x03 \x01(\x0b\x32\n.SstResult\"C\n\nXstRequest\x12\x15\n\rantenna_field\x18\x01 \x01(\t\x12\x13\n\x06maxage\x18\x02 \x01(\rH\x00\x88\x01\x01\x42\t\n\x07_maxage\"\xe4\x03\n\tXstResult\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x0e\x66requency_band\x18\x02 \x01(\x0b\x32\x0e.FrequencyBand\x12\x1c\n\x14integration_interval\x18\x03 \x01(\x02\x12\x0f\n\x07subband\x18\x04 \x01(\x05\x12\x11\n\tfrequency\x18\x05 \x01(\x02\x12)\n\tbaselines\x18\x06 \x03(\x0b\x32\x16.XstResult.XstBaseline\x1a\x92\x02\n\x0bXstBaseline\x12\x10\n\x08\x61ntenna1\x18\x01 \x01(\x05\x12\x10\n\x08\x61ntenna2\x18\x02 \x01(\x05\x12+\n\x02xx\x18\x03 \x01(\x0b\x32\x1f.XstResult.XstBaseline.XstValue\x12+\n\x02xy\x18\x04 \x01(\x0b\x32\x1f.XstResult.XstBaseline.XstValue\x12+\n\x02yx\x18\x05 \x01(\x0b\x32\x1f.XstResult.XstBaseline.XstValue\x12+\n\x02yy\x18\x06 \x01(\x0b\x32\x1f.XstResult.XstBaseline.XstValue\x1a+\n\x08XstValue\x12\x10\n\x08power_db\x18\x01 \x01(\x02\x12\r\n\x05phase\x18\x02 \x01(\x02\"&\n\x08XstReply\x12\x1a\n\x06result\x18\x03 \x01(\x0b\x32\n.XstResult2o\n\nStatistics\x12\x1f\n\x03\x42st\x12\x0b.BstRequest\x1a\t.BstReply\"\x00\x12\x1f\n\x03Sst\x12\x0b.SstRequest\x1a\t.SstReply\"\x00\x12\x1f\n\x03Xst\x12\x0b.XstRequest\x1a\t.XstReply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lofar_sid.interface.stationcontrol.statistics_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FREQUENCYBAND']._serialized_start=88
  _globals['_FREQUENCYBAND']._serialized_end=162
  _globals['_BSTREQUEST']._serialized_start=164
  _globals['_BSTREQUEST']._serialized_end=231
  _globals['_BSTRESULT']._serialized_start=234
  _globals['_BSTRESULT']._serialized_end=474
  _globals['_BSTRESULT_BSTBEAMLET']._serialized_start=405
  _globals['_BSTRESULT_BSTBEAMLET']._serialized_end=474
  _globals['_BSTREPLY']._serialized_start=476
  _globals['_BSTREPLY']._serialized_end=514
  _globals['_SSTREQUEST']._serialized_start=516
  _globals['_SSTREQUEST']._serialized_end=583
  _globals['_SSTRESULT']._serialized_start=586
  _globals['_SSTRESULT']._serialized_end=929
  _globals['_SSTRESULT_SSTSUBBAND']._serialized_start=758
  _globals['_SSTRESULT_SSTSUBBAND']._serialized_end=929
  _globals['_SSTRESULT_SSTSUBBAND_SSTANTENNA']._serialized_start=860
  _globals['_SSTRESULT_SSTSUBBAND_SSTANTENNA']._serialized_end=929
  _globals['_SSTREPLY']._serialized_start=931
  _globals['_SSTREPLY']._serialized_end=969
  _globals['_XSTREQUEST']._serialized_start=971
  _globals['_XSTREQUEST']._serialized_end=1038
  _globals['_XSTRESULT']._serialized_start=1041
  _globals['_XSTRESULT']._serialized_end=1525
  _globals['_XSTRESULT_XSTBASELINE']._serialized_start=1251
  _globals['_XSTRESULT_XSTBASELINE']._serialized_end=1525
  _globals['_XSTRESULT_XSTBASELINE_XSTVALUE']._serialized_start=1482
  _globals['_XSTRESULT_XSTBASELINE_XSTVALUE']._serialized_end=1525
  _globals['_XSTREPLY']._serialized_start=1527
  _globals['_XSTREPLY']._serialized_end=1565
  _globals['_STATISTICS']._serialized_start=1567
  _globals['_STATISTICS']._serialized_end=1678
# @@protoc_insertion_point(module_scope)
