# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lofar_sid/interface/stationcontrol/antennafield.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'lofar_sid/interface/stationcontrol/antennafield.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5lofar_sid/interface/stationcontrol/antennafield.proto\"2\n\x16\x41ntennafieldIdentifier\x12\x18\n\x10\x61ntenna_field_id\x18\x01 \x01(\t\"w\n\x16SetAntennafieldRequest\x12+\n\nidentifier\x18\x01 \x01(\x0b\x32\x17.AntennafieldIdentifier\x12\x30\n\x0cpower_status\x18\x02 \x01(\x0e\x32\x1a.Antennafield_Power_Status\"E\n\x16GetAntennafieldRequest\x12+\n\nidentifier\x18\x01 \x01(\x0b\x32\x17.AntennafieldIdentifier\"s\n\x12\x41ntennafieldResult\x12+\n\nidentifier\x18\x01 \x01(\x0b\x32\x17.AntennafieldIdentifier\x12\x30\n\x0cpower_status\x18\x02 \x01(\x0e\x32\x1a.Antennafield_Power_Status\"\\\n\x11\x41ntennafieldReply\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x11\n\texception\x18\x02 \x01(\t\x12#\n\x06result\x18\x03 \x01(\x0b\x32\x13.AntennafieldResult*R\n\x19\x41ntennafield_Power_Status\x12\x1a\n\x16\x41ntennafield_POWER_OFF\x10\x00\x12\x19\n\x15\x41ntennafield_POWER_ON\x10\x01\x32\x9c\x01\n\x0c\x41ntennafield\x12\x45\n\x14GetAntennafieldPower\x12\x17.GetAntennafieldRequest\x1a\x12.AntennafieldReply\"\x00\x12\x45\n\x14SetAntennafieldPower\x12\x17.SetAntennafieldRequest\x1a\x12.AntennafieldReply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lofar_sid.interface.stationcontrol.antennafield_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANTENNAFIELD_POWER_STATUS']._serialized_start=512
  _globals['_ANTENNAFIELD_POWER_STATUS']._serialized_end=594
  _globals['_ANTENNAFIELDIDENTIFIER']._serialized_start=57
  _globals['_ANTENNAFIELDIDENTIFIER']._serialized_end=107
  _globals['_SETANTENNAFIELDREQUEST']._serialized_start=109
  _globals['_SETANTENNAFIELDREQUEST']._serialized_end=228
  _globals['_GETANTENNAFIELDREQUEST']._serialized_start=230
  _globals['_GETANTENNAFIELDREQUEST']._serialized_end=299
  _globals['_ANTENNAFIELDRESULT']._serialized_start=301
  _globals['_ANTENNAFIELDRESULT']._serialized_end=416
  _globals['_ANTENNAFIELDREPLY']._serialized_start=418
  _globals['_ANTENNAFIELDREPLY']._serialized_end=510
  _globals['_ANTENNAFIELD']._serialized_start=597
  _globals['_ANTENNAFIELD']._serialized_end=753
# @@protoc_insertion_point(module_scope)
