# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lofar_sid/interface/stationcontrol/antenna.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'lofar_sid/interface/stationcontrol/antenna.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0lofar_sid/interface/stationcontrol/antenna.proto\"=\n\nIdentifier\x12\x19\n\x11\x61ntennafield_name\x18\x01 \x01(\t\x12\x14\n\x0c\x61ntenna_name\x18\x02 \x01(\t\"c\n\x17SetAntennaStatusRequest\x12\x1f\n\nidentifier\x18\x01 \x01(\x0b\x32\x0b.Identifier\x12\'\n\x0e\x61ntenna_status\x18\x02 \x01(\x0e\x32\x0f.Antenna_Status\"4\n\x11GetAntennaRequest\x12\x1f\n\nidentifier\x18\x01 \x01(\x0b\x32\x0b.Identifier\"Z\n\x14SetAntennaUseRequest\x12\x1f\n\nidentifier\x18\x01 \x01(\x0b\x32\x0b.Identifier\x12!\n\x0b\x61ntenna_use\x18\x02 \x01(\x0e\x32\x0c.Antenna_Use\"|\n\rAntennaResult\x12\x1f\n\nidentifier\x18\x01 \x01(\x0b\x32\x0b.Identifier\x12!\n\x0b\x61ntenna_use\x18\x02 \x01(\x0e\x32\x0c.Antenna_Use\x12\'\n\x0e\x61ntenna_status\x18\x03 \x01(\x0e\x32\x0f.Antenna_Status\"R\n\x0c\x41ntennaReply\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x11\n\texception\x18\x02 \x01(\t\x12\x1e\n\x06result\x18\x03 \x01(\x0b\x32\x0e.AntennaResult*Z\n\x0e\x41ntenna_Status\x12\x06\n\x02OK\x10\x00\x12\x0e\n\nSUSPICIOUS\x10\x01\x12\n\n\x06\x42ROKEN\x10\x02\x12\x11\n\rBEYOND_REPAIR\x10\x03\x12\x11\n\rNOT_AVAILABLE\x10\x04*(\n\x0b\x41ntenna_Use\x12\x08\n\x04\x41UTO\x10\x00\x12\x06\n\x02ON\x10\x01\x12\x07\n\x03OFF\x10\x02\x32\xb4\x01\n\x07\x41ntenna\x12\x31\n\nGetAntenna\x12\x12.GetAntennaRequest\x1a\r.AntennaReply\"\x00\x12=\n\x10SetAntennaStatus\x12\x18.SetAntennaStatusRequest\x1a\r.AntennaReply\"\x00\x12\x37\n\rSetAntennaUse\x12\x15.SetAntennaUseRequest\x1a\r.AntennaReply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lofar_sid.interface.stationcontrol.antenna_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANTENNA_STATUS']._serialized_start=572
  _globals['_ANTENNA_STATUS']._serialized_end=662
  _globals['_ANTENNA_USE']._serialized_start=664
  _globals['_ANTENNA_USE']._serialized_end=704
  _globals['_IDENTIFIER']._serialized_start=52
  _globals['_IDENTIFIER']._serialized_end=113
  _globals['_SETANTENNASTATUSREQUEST']._serialized_start=115
  _globals['_SETANTENNASTATUSREQUEST']._serialized_end=214
  _globals['_GETANTENNAREQUEST']._serialized_start=216
  _globals['_GETANTENNAREQUEST']._serialized_end=268
  _globals['_SETANTENNAUSEREQUEST']._serialized_start=270
  _globals['_SETANTENNAUSEREQUEST']._serialized_end=360
  _globals['_ANTENNARESULT']._serialized_start=362
  _globals['_ANTENNARESULT']._serialized_end=486
  _globals['_ANTENNAREPLY']._serialized_start=488
  _globals['_ANTENNAREPLY']._serialized_end=570
  _globals['_ANTENNA']._serialized_start=707
  _globals['_ANTENNA']._serialized_end=887
# @@protoc_insertion_point(module_scope)
