# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lofar_sid/interface/stationcontrol/observation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'lofar_sid/interface/stationcontrol/observation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4lofar_sid/interface/stationcontrol/observation.proto\"0\n\x17StartObservationRequest\x12\x15\n\rconfiguration\x18\x01 \x01(\t\"0\n\x16StopObservationRequest\x12\x16\n\x0eobservation_id\x18\x01 \x01(\x03\"6\n\x10ObservationReply\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x11\n\texception\x18\x02 \x01(\t2\x91\x01\n\x0bObservation\x12\x41\n\x10StartObservation\x12\x18.StartObservationRequest\x1a\x11.ObservationReply\"\x00\x12?\n\x0fStopObservation\x12\x17.StopObservationRequest\x1a\x11.ObservationReply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lofar_sid.interface.stationcontrol.observation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_STARTOBSERVATIONREQUEST']._serialized_start=56
  _globals['_STARTOBSERVATIONREQUEST']._serialized_end=104
  _globals['_STOPOBSERVATIONREQUEST']._serialized_start=106
  _globals['_STOPOBSERVATIONREQUEST']._serialized_end=154
  _globals['_OBSERVATIONREPLY']._serialized_start=156
  _globals['_OBSERVATIONREPLY']._serialized_end=210
  _globals['_OBSERVATION']._serialized_start=213
  _globals['_OBSERVATION']._serialized_end=358
# @@protoc_insertion_point(module_scope)
