# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from lofar_sid.interface.stationcontrol import station_pb2 as lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2

GRPC_GENERATED_VERSION = '1.71.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in lofar_sid/interface/stationcontrol/station_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class StationStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetStationState = channel.unary_unary(
                '/station_control.station.Station/GetStationState',
                request_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.GetStationStateRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
                _registered_method=True)
        self.SetStationState = channel.unary_stream(
                '/station_control.station.Station/SetStationState',
                request_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.SetStationStateRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
                _registered_method=True)
        self.SoftStationReset = channel.unary_stream(
                '/station_control.station.Station/SoftStationReset',
                request_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.SoftStationResetRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
                _registered_method=True)
        self.HardStationReset = channel.unary_stream(
                '/station_control.station.Station/HardStationReset',
                request_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.HardStationResetRequest.SerializeToString,
                response_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
                _registered_method=True)


class StationServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetStationState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetStationState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SoftStationReset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HardStationReset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetStationState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStationState,
                    request_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.GetStationStateRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.SerializeToString,
            ),
            'SetStationState': grpc.unary_stream_rpc_method_handler(
                    servicer.SetStationState,
                    request_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.SetStationStateRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.SerializeToString,
            ),
            'SoftStationReset': grpc.unary_stream_rpc_method_handler(
                    servicer.SoftStationReset,
                    request_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.SoftStationResetRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.SerializeToString,
            ),
            'HardStationReset': grpc.unary_stream_rpc_method_handler(
                    servicer.HardStationReset,
                    request_deserializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.HardStationResetRequest.FromString,
                    response_serializer=lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'station_control.station.Station', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('station_control.station.Station', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Station(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetStationState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/station_control.station.Station/GetStationState',
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.GetStationStateRequest.SerializeToString,
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetStationState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/station_control.station.Station/SetStationState',
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.SetStationStateRequest.SerializeToString,
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SoftStationReset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/station_control.station.Station/SoftStationReset',
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.SoftStationResetRequest.SerializeToString,
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HardStationReset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/station_control.station.Station/HardStationReset',
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.HardStationResetRequest.SerializeToString,
            lofar__sid_dot_interface_dot_stationcontrol_dot_station__pb2.StationStateReply.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
