# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lofar_sid/interface/opah/grafana-apiv3.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'lofar_sid/interface/opah/grafana-apiv3.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,lofar_sid/interface/opah/grafana-apiv3.proto\x12\tgrafanav3\x1a\x1fgoogle/protobuf/timestamp.proto\"N\n\x12ListMetricsRequest\x12(\n\ndimensions\x18\x01 \x03(\x0b\x32\x14.grafanav3.Dimension\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\"z\n\x13ListMetricsResponse\x12\x36\n\x07Metrics\x18\x01 \x03(\x0b\x32%.grafanav3.ListMetricsResponse.Metric\x1a+\n\x06Metric\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\x9e\x02\n\x15GetMetricValueRequest\x12(\n\ndimensions\x18\x01 \x03(\x0b\x32\x14.grafanav3.Dimension\x12\x0f\n\x07metrics\x18\x02 \x03(\t\x12>\n\x07options\x18\x03 \x03(\x0b\x32-.grafanav3.GetMetricValueRequest.OptionsEntry\x12-\n\tstartDate\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x65ndDate\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xeb\x01\n\x16GetMetricValueResponse\x12\x37\n\x06\x66rames\x18\x01 \x03(\x0b\x32\'.grafanav3.GetMetricValueResponse.Frame\x1a\x97\x01\n\x05\x46rame\x12\x0e\n\x06metric\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x06\x66ields\x18\x03 \x03(\x0b\x32\x1b.grafanav3.SingleValueField\x12\"\n\x04meta\x18\x04 \x01(\x0b\x32\x14.grafanav3.FrameMeta\"\xa1\x02\n\x11GetOptionsRequest\x12\x39\n\tqueryType\x18\x01 \x01(\x0e\x32&.grafanav3.GetOptionsRequest.QueryType\x12J\n\x0fselectedOptions\x18\x02 \x03(\x0b\x32\x31.grafanav3.GetOptionsRequest.SelectedOptionsEntry\x1a\x36\n\x14SelectedOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"M\n\tQueryType\x12\x14\n\x10GetMetricHistory\x10\x00\x12\x12\n\x0eGetMetricValue\x10\x01\x12\x16\n\x12GetMetricAggregate\x10\x02\"L\n\tEnumValue\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x04 \x01(\x08\"\xb9\x01\n\x06Option\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12$\n\x04type\x18\x03 \x01(\x0e\x32\x16.grafanav3.Option.Type\x12(\n\nenumValues\x18\x04 \x03(\x0b\x32\x14.grafanav3.EnumValue\x12\x10\n\x08required\x18\x05 \x01(\x08\x12\r\n\x05label\x18\x06 \x01(\t\"\x1d\n\x04Type\x12\x08\n\x04\x45num\x10\x00\x12\x0b\n\x07\x42oolean\x10\x01\"8\n\x12GetOptionsResponse\x12\"\n\x07options\x18\x01 \x03(\x0b\x32\x11.grafanav3.Option\"\x92\x03\n\x19GetMetricAggregateRequest\x12(\n\ndimensions\x18\x01 \x03(\x0b\x32\x14.grafanav3.Dimension\x12\x0f\n\x07metrics\x18\x02 \x03(\t\x12-\n\tstartDate\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x65ndDate\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08maxItems\x18\x06 \x01(\x03\x12-\n\x0ctimeOrdering\x18\x07 \x01(\x0e\x32\x17.grafanav3.TimeOrdering\x12\x15\n\rstartingToken\x18\x08 \x01(\t\x12\x12\n\nintervalMs\x18\t \x01(\x03\x12\x42\n\x07options\x18\n \x03(\x0b\x32\x31.grafanav3.GetMetricAggregateRequest.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x1aGetMetricAggregateResponse\x12 \n\x06\x66rames\x18\x01 \x03(\x0b\x32\x10.grafanav3.Frame\x12\x11\n\tnextToken\x18\x02 \x01(\t\"\xfa\x02\n\x17GetMetricHistoryRequest\x12(\n\ndimensions\x18\x03 \x03(\x0b\x32\x14.grafanav3.Dimension\x12\x0f\n\x07metrics\x18\x04 \x03(\t\x12-\n\tstartDate\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x65ndDate\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08maxItems\x18\x07 \x01(\x03\x12-\n\x0ctimeOrdering\x18\x08 \x01(\x0e\x32\x17.grafanav3.TimeOrdering\x12\x15\n\rstartingToken\x18\t \x01(\t\x12@\n\x07options\x18\n \x03(\x0b\x32/.grafanav3.GetMetricHistoryRequest.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"O\n\x18GetMetricHistoryResponse\x12 \n\x06\x66rames\x18\x01 \x03(\x0b\x32\x10.grafanav3.Frame\x12\x11\n\tnextToken\x18\x02 \x01(\t\"#\n\x05Label\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x80\x01\n\x05\x46ield\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x06labels\x18\x02 \x03(\x0b\x32\x10.grafanav3.Label\x12!\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x11.grafanav3.config\x12\x0e\n\x06values\x18\x04 \x03(\x01\x12\x14\n\x0cstringValues\x18\x05 \x03(\t\"T\n\x0cValueMapping\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x01\x12\n\n\x02to\x18\x02 \x01(\x01\x12\r\n\x05value\x18\x03 \x01(\t\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\r\n\x05\x63olor\x18\x05 \x01(\t\"A\n\x06\x63onfig\x12\x0c\n\x04unit\x18\x01 \x01(\t\x12)\n\x08Mappings\x18\x02 \x03(\x0b\x32\x17.grafanav3.ValueMapping\"\x89\x01\n\x10SingleValueField\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x06labels\x18\x02 \x03(\x0b\x32\x10.grafanav3.Label\x12!\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x11.grafanav3.config\x12\r\n\x05value\x18\x04 \x01(\x01\x12\x13\n\x0bstringValue\x18\x05 \x01(\t\"\x8d\x01\n\x05\x46rame\x12\x0e\n\x06metric\x18\x01 \x01(\t\x12.\n\ntimestamps\x18\x02 \x03(\x0b\x32\x1a.google.protobuf.Timestamp\x12 \n\x06\x66ields\x18\x03 \x03(\x0b\x32\x10.grafanav3.Field\x12\"\n\x04meta\x18\x04 \x01(\x0b\x32\x14.grafanav3.FrameMeta\"\xcf\x06\n\tFrameMeta\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x1e.grafanav3.FrameMeta.FrameType\x12,\n\x07Notices\x18\x06 \x03(\x0b\x32\x1b.grafanav3.FrameMeta.Notice\x12<\n\x16PreferredVisualization\x18\x08 \x01(\x0e\x32\x1c.grafanav3.FrameMeta.VisType\x12\x1b\n\x13\x65xecutedQueryString\x18\t \x01(\t\x1a\xf4\x02\n\x06Notice\x12<\n\x08Severity\x18\x01 \x01(\x0e\x32*.grafanav3.FrameMeta.Notice.NoticeSeverity\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\x12\x38\n\x07inspect\x18\x04 \x01(\x0e\x32\'.grafanav3.FrameMeta.Notice.InspectType\"\\\n\x0eNoticeSeverity\x12\x16\n\x12NoticeSeverityInfo\x10\x00\x12\x19\n\x15NoticeSeverityWarning\x10\x01\x12\x17\n\x13NoticeSeverityError\x10\x03\"x\n\x0bInspectType\x12\x13\n\x0fInspectTypeNone\x10\x00\x12\x13\n\x0fInspectTypeMeta\x10\x01\x12\x14\n\x10InspectTypeError\x10\x02\x12\x13\n\x0fInspectTypeData\x10\x03\x12\x14\n\x10InspectTypeStats\x10\x04\"\xab\x01\n\tFrameType\x12\x14\n\x10\x46rameTypeUnknown\x10\x00\x12\x1b\n\x17\x46rameTypeTimeSeriesWide\x10\x01\x12\x1b\n\x17\x46rameTypeTimeSeriesLong\x10\x02\x12\x1b\n\x17\x46rameTypeTimeSeriesMany\x10\x03\x12\x1d\n\x19\x46rameTypeDirectoryListing\x10\x04\x12\x12\n\x0e\x46rameTypeTable\x10\x05\"f\n\x07VisType\x12\x10\n\x0cVisTypeGraph\x10\x00\x12\x10\n\x0cVisTypeTable\x10\x01\x12\x0f\n\x0bVisTypeLogs\x10\x02\x12\x10\n\x0cVisTypeTrace\x10\x03\x12\x14\n\x10VisTypeNodeGraph\x10\x04\"]\n\x18ListDimensionKeysRequest\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\x31\n\x13selected_dimensions\x18\x02 \x03(\x0b\x32\x14.grafanav3.Dimension\"\x85\x01\n\x19ListDimensionKeysResponse\x12<\n\x07results\x18\x01 \x03(\x0b\x32+.grafanav3.ListDimensionKeysResponse.Result\x1a*\n\x06Result\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"v\n\x1aListDimensionValuesRequest\x12\x15\n\rdimension_key\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x31\n\x13selected_dimensions\x18\x03 \x03(\x0b\x32\x14.grafanav3.Dimension\"\x8b\x01\n\x1bListDimensionValuesResponse\x12>\n\x07results\x18\x01 \x03(\x0b\x32-.grafanav3.ListDimensionValuesResponse.Result\x1a,\n\x06Result\x12\r\n\x05value\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"3\n\tTimeRange\x12\x13\n\x0b\x66romEpochMS\x18\x01 \x01(\x03\x12\x11\n\ttoEpochMS\x18\x02 \x01(\x03\"\'\n\tDimension\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xad\x01\n\x0cQueryRequest\x12\r\n\x05refId\x18\x01 \x01(\t\x12\x15\n\rmaxDataPoints\x18\x02 \x01(\x03\x12\x12\n\nintervalMS\x18\x03 \x01(\x03\x12\'\n\ttimeRange\x18\x04 \x01(\x0b\x32\x14.grafanav3.TimeRange\x12\x10\n\x08startKey\x18\x05 \x01(\x03\x12(\n\ndimensions\x18\x06 \x03(\x0b\x32\x14.grafanav3.Dimension\"\x8a\x01\n\rQueryResponse\x12\r\n\x05refId\x18\x01 \x01(\t\x12\x0f\n\x07nextKey\x18\x02 \x01(\x03\x12.\n\x06values\x18\x03 \x03(\x0b\x32\x1e.grafanav3.QueryResponse.Value\x1a)\n\x05Value\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x02*-\n\x0cTimeOrdering\x12\r\n\tASCENDING\x10\x00\x12\x0e\n\nDESCENDING\x10\x01\x32\x9a\x05\n\x0fGrafanaQueryAPI\x12`\n\x11ListDimensionKeys\x12#.grafanav3.ListDimensionKeysRequest\x1a$.grafanav3.ListDimensionKeysResponse\"\x00\x12\x66\n\x13ListDimensionValues\x12%.grafanav3.ListDimensionValuesRequest\x1a&.grafanav3.ListDimensionValuesResponse\"\x00\x12N\n\x0bListMetrics\x12\x1d.grafanav3.ListMetricsRequest\x1a\x1e.grafanav3.ListMetricsResponse\"\x00\x12P\n\x0fGetQueryOptions\x12\x1c.grafanav3.GetOptionsRequest\x1a\x1d.grafanav3.GetOptionsResponse\"\x00\x12W\n\x0eGetMetricValue\x12 .grafanav3.GetMetricValueRequest\x1a!.grafanav3.GetMetricValueResponse\"\x00\x12]\n\x10GetMetricHistory\x12\".grafanav3.GetMetricHistoryRequest\x1a#.grafanav3.GetMetricHistoryResponse\"\x00\x12\x63\n\x12GetMetricAggregate\x12$.grafanav3.GetMetricAggregateRequest\x1a%.grafanav3.GetMetricAggregateResponse\"\x00\x42\x38Z6bitbucket.org/innius/grafana-simple-grpc-datasource/v3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lofar_sid.interface.opah.grafana_apiv3_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6bitbucket.org/innius/grafana-simple-grpc-datasource/v3'
  _globals['_GETMETRICVALUEREQUEST_OPTIONSENTRY']._loaded_options = None
  _globals['_GETMETRICVALUEREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_GETOPTIONSREQUEST_SELECTEDOPTIONSENTRY']._loaded_options = None
  _globals['_GETOPTIONSREQUEST_SELECTEDOPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_GETMETRICAGGREGATEREQUEST_OPTIONSENTRY']._loaded_options = None
  _globals['_GETMETRICAGGREGATEREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_GETMETRICHISTORYREQUEST_OPTIONSENTRY']._loaded_options = None
  _globals['_GETMETRICHISTORYREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_TIMEORDERING']._serialized_start=4748
  _globals['_TIMEORDERING']._serialized_end=4793
  _globals['_LISTMETRICSREQUEST']._serialized_start=92
  _globals['_LISTMETRICSREQUEST']._serialized_end=170
  _globals['_LISTMETRICSRESPONSE']._serialized_start=172
  _globals['_LISTMETRICSRESPONSE']._serialized_end=294
  _globals['_LISTMETRICSRESPONSE_METRIC']._serialized_start=251
  _globals['_LISTMETRICSRESPONSE_METRIC']._serialized_end=294
  _globals['_GETMETRICVALUEREQUEST']._serialized_start=297
  _globals['_GETMETRICVALUEREQUEST']._serialized_end=583
  _globals['_GETMETRICVALUEREQUEST_OPTIONSENTRY']._serialized_start=537
  _globals['_GETMETRICVALUEREQUEST_OPTIONSENTRY']._serialized_end=583
  _globals['_GETMETRICVALUERESPONSE']._serialized_start=586
  _globals['_GETMETRICVALUERESPONSE']._serialized_end=821
  _globals['_GETMETRICVALUERESPONSE_FRAME']._serialized_start=670
  _globals['_GETMETRICVALUERESPONSE_FRAME']._serialized_end=821
  _globals['_GETOPTIONSREQUEST']._serialized_start=824
  _globals['_GETOPTIONSREQUEST']._serialized_end=1113
  _globals['_GETOPTIONSREQUEST_SELECTEDOPTIONSENTRY']._serialized_start=980
  _globals['_GETOPTIONSREQUEST_SELECTEDOPTIONSENTRY']._serialized_end=1034
  _globals['_GETOPTIONSREQUEST_QUERYTYPE']._serialized_start=1036
  _globals['_GETOPTIONSREQUEST_QUERYTYPE']._serialized_end=1113
  _globals['_ENUMVALUE']._serialized_start=1115
  _globals['_ENUMVALUE']._serialized_end=1191
  _globals['_OPTION']._serialized_start=1194
  _globals['_OPTION']._serialized_end=1379
  _globals['_OPTION_TYPE']._serialized_start=1350
  _globals['_OPTION_TYPE']._serialized_end=1379
  _globals['_GETOPTIONSRESPONSE']._serialized_start=1381
  _globals['_GETOPTIONSRESPONSE']._serialized_end=1437
  _globals['_GETMETRICAGGREGATEREQUEST']._serialized_start=1440
  _globals['_GETMETRICAGGREGATEREQUEST']._serialized_end=1842
  _globals['_GETMETRICAGGREGATEREQUEST_OPTIONSENTRY']._serialized_start=537
  _globals['_GETMETRICAGGREGATEREQUEST_OPTIONSENTRY']._serialized_end=583
  _globals['_GETMETRICAGGREGATERESPONSE']._serialized_start=1844
  _globals['_GETMETRICAGGREGATERESPONSE']._serialized_end=1925
  _globals['_GETMETRICHISTORYREQUEST']._serialized_start=1928
  _globals['_GETMETRICHISTORYREQUEST']._serialized_end=2306
  _globals['_GETMETRICHISTORYREQUEST_OPTIONSENTRY']._serialized_start=537
  _globals['_GETMETRICHISTORYREQUEST_OPTIONSENTRY']._serialized_end=583
  _globals['_GETMETRICHISTORYRESPONSE']._serialized_start=2308
  _globals['_GETMETRICHISTORYRESPONSE']._serialized_end=2387
  _globals['_LABEL']._serialized_start=2389
  _globals['_LABEL']._serialized_end=2424
  _globals['_FIELD']._serialized_start=2427
  _globals['_FIELD']._serialized_end=2555
  _globals['_VALUEMAPPING']._serialized_start=2557
  _globals['_VALUEMAPPING']._serialized_end=2641
  _globals['_CONFIG']._serialized_start=2643
  _globals['_CONFIG']._serialized_end=2708
  _globals['_SINGLEVALUEFIELD']._serialized_start=2711
  _globals['_SINGLEVALUEFIELD']._serialized_end=2848
  _globals['_FRAME']._serialized_start=2851
  _globals['_FRAME']._serialized_end=2992
  _globals['_FRAMEMETA']._serialized_start=2995
  _globals['_FRAMEMETA']._serialized_end=3842
  _globals['_FRAMEMETA_NOTICE']._serialized_start=3192
  _globals['_FRAMEMETA_NOTICE']._serialized_end=3564
  _globals['_FRAMEMETA_NOTICE_NOTICESEVERITY']._serialized_start=3350
  _globals['_FRAMEMETA_NOTICE_NOTICESEVERITY']._serialized_end=3442
  _globals['_FRAMEMETA_NOTICE_INSPECTTYPE']._serialized_start=3444
  _globals['_FRAMEMETA_NOTICE_INSPECTTYPE']._serialized_end=3564
  _globals['_FRAMEMETA_FRAMETYPE']._serialized_start=3567
  _globals['_FRAMEMETA_FRAMETYPE']._serialized_end=3738
  _globals['_FRAMEMETA_VISTYPE']._serialized_start=3740
  _globals['_FRAMEMETA_VISTYPE']._serialized_end=3842
  _globals['_LISTDIMENSIONKEYSREQUEST']._serialized_start=3844
  _globals['_LISTDIMENSIONKEYSREQUEST']._serialized_end=3937
  _globals['_LISTDIMENSIONKEYSRESPONSE']._serialized_start=3940
  _globals['_LISTDIMENSIONKEYSRESPONSE']._serialized_end=4073
  _globals['_LISTDIMENSIONKEYSRESPONSE_RESULT']._serialized_start=4031
  _globals['_LISTDIMENSIONKEYSRESPONSE_RESULT']._serialized_end=4073
  _globals['_LISTDIMENSIONVALUESREQUEST']._serialized_start=4075
  _globals['_LISTDIMENSIONVALUESREQUEST']._serialized_end=4193
  _globals['_LISTDIMENSIONVALUESRESPONSE']._serialized_start=4196
  _globals['_LISTDIMENSIONVALUESRESPONSE']._serialized_end=4335
  _globals['_LISTDIMENSIONVALUESRESPONSE_RESULT']._serialized_start=4291
  _globals['_LISTDIMENSIONVALUESRESPONSE_RESULT']._serialized_end=4335
  _globals['_TIMERANGE']._serialized_start=4337
  _globals['_TIMERANGE']._serialized_end=4388
  _globals['_DIMENSION']._serialized_start=4390
  _globals['_DIMENSION']._serialized_end=4429
  _globals['_QUERYREQUEST']._serialized_start=4432
  _globals['_QUERYREQUEST']._serialized_end=4605
  _globals['_QUERYRESPONSE']._serialized_start=4608
  _globals['_QUERYRESPONSE']._serialized_end=4746
  _globals['_QUERYRESPONSE_VALUE']._serialized_start=4705
  _globals['_QUERYRESPONSE_VALUE']._serialized_end=4746
  _globals['_GRAFANAQUERYAPI']._serialized_start=4796
  _globals['_GRAFANAQUERYAPI']._serialized_end=5462
# @@protoc_insertion_point(module_scope)
