syntax = "proto3";

service Observation {
  rpc StartObservation(StartObservationRequest) returns (ObservationReply){}
  rpc StopObservation(StopObservationRequest) returns (ObservationReply) {}
}

message StartObservationRequest {
  string configuration = 1;
}
message StopObservationRequest {
  int64 observation_id = 1;
}

message ObservationReply {
  bool success = 1;
  string exception = 2;
}
