# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lofar_sid/interface/stationcontrol/station.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'lofar_sid/interface/stationcontrol/station.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0lofar_sid/interface/stationcontrol/station.proto\x12\x17station_control.station\"W\n\x16SetStationStateRequest\x12=\n\rstation_state\x18\x01 \x01(\x0e\x32&.station_control.station.Station_State\"\x18\n\x16GetStationStateRequest\"\x19\n\x17SoftStationResetRequest\"\x19\n\x17HardStationResetRequest\"S\n\x12StationStateResult\x12=\n\rstation_state\x18\x01 \x01(\x0e\x32&.station_control.station.Station_State\"P\n\x11StationStateReply\x12;\n\x06result\x18\x01 \x01(\x0b\x32+.station_control.station.StationStateResult*<\n\rStation_State\x12\x07\n\x03OFF\x10\x00\x12\r\n\tHIBERNATE\x10\x01\x12\x0b\n\x07STANDBY\x10\x02\x12\x06\n\x02ON\x10\x03\x32\xdb\x03\n\x07Station\x12p\n\x0fGetStationState\x12/.station_control.station.GetStationStateRequest\x1a*.station_control.station.StationStateReply\"\x00\x12r\n\x0fSetStationState\x12/.station_control.station.SetStationStateRequest\x1a*.station_control.station.StationStateReply\"\x00\x30\x01\x12t\n\x10SoftStationReset\x12\x30.station_control.station.SoftStationResetRequest\x1a*.station_control.station.StationStateReply\"\x00\x30\x01\x12t\n\x10HardStationReset\x12\x30.station_control.station.HardStationResetRequest\x1a*.station_control.station.StationStateReply\"\x00\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lofar_sid.interface.stationcontrol.station_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_STATION_STATE']._serialized_start=413
  _globals['_STATION_STATE']._serialized_end=473
  _globals['_SETSTATIONSTATEREQUEST']._serialized_start=77
  _globals['_SETSTATIONSTATEREQUEST']._serialized_end=164
  _globals['_GETSTATIONSTATEREQUEST']._serialized_start=166
  _globals['_GETSTATIONSTATEREQUEST']._serialized_end=190
  _globals['_SOFTSTATIONRESETREQUEST']._serialized_start=192
  _globals['_SOFTSTATIONRESETREQUEST']._serialized_end=217
  _globals['_HARDSTATIONRESETREQUEST']._serialized_start=219
  _globals['_HARDSTATIONRESETREQUEST']._serialized_end=244
  _globals['_STATIONSTATERESULT']._serialized_start=246
  _globals['_STATIONSTATERESULT']._serialized_end=329
  _globals['_STATIONSTATEREPLY']._serialized_start=331
  _globals['_STATIONSTATEREPLY']._serialized_end=411
  _globals['_STATION']._serialized_start=476
  _globals['_STATION']._serialized_end=951
# @@protoc_insertion_point(module_scope)
